@@ -1,6 +1,8 @@
 import json
+import rfc3339
 from datetime import datetime
 import time
+import pytz
 class InstanceInfo:
     def __init__(self,name="stat-api",startupAt=None,version_file=None):
         self.name=name
@@ -11,7 +13,7 @@ class InstanceInfo:
         self.info=s
 
     def toMap(self):
-        dt = datetime.now()
+        dt = datetime.now(pytz.UTC)
         return {"name": self.name,"startupAt": self.startupAt.strftime("%Y-%m-%dT%H:%M:%SZ"),"date":dt.strftime("%Y-%m-%dT%H:%M:%SZ"),"info":self.info}
 
 #zookeeper中service的注册信息
