@@ -137,6 +137,38 @@ class RDBService:
             self.close()
             raise e
 
+    def drop_table(self, table):
+        try:
+            if self.conn is None:
+                self.__connect()
+            sql = 'drop table if exists {}'.format(table)
+            cusor = self.conn.cursor()
+            res = cusor.execute(sql)
+            self.conn.commit()
+            cusor.close()
+            # logging.debug('数据删除成功！')
+        except Exception as e:
+            traceback.print_exc()
+            logging.warning('while excute droppping {}'.format(table))
+            self.close()
+            raise e
+
+    def delete(self, table, query):
+        try:
+            if self.conn is None:
+                self.__connect()
+            sql = 'delete from {} {}'.format(table, query)
+            cusor = self.conn.cursor()
+            res = cusor.execute(sql)
+            self.conn.commit()
+            cusor.close()
+            # logging.debug('数据删除成功！')
+        except Exception as e:
+            traceback.print_exc()
+            logging.warning('while excute deleting sql with query({}) in {}'.format(table, query))
+            self.close()
+            raise e
+
     def count(self, table, query):
         try:
             if self.conn is None:
